@@ -1,9 +1,10 @@
 package Gtk2::Phat;
 
+use strict;
 use Gtk2;
 require DynaLoader;
 our @ISA = qw(DynaLoader);
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 sub dl_load_flags { 0x01 };
 
@@ -25,11 +26,11 @@ L<Gtk2>(3pm), L<Gtk2::Phat::index>(3pm)
 
 =head1 AUTHOR
 
-Florian Ragwitz <flora@cpan.org>
+Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005 by Florian Ragwitz
+Copyright (C) 2005, 2006 by Florian Ragwitz
 
 This library is free software; you can redistribute it and/or modify it under
 the terms of the GNU Library General Public License as published by the Free
